@@ -34,4 +34,9 @@ public class InstrumentedResource {
         }
         return "fuh";
     }
+
+    @Path("/subresource")
+    public InstrumentedSubResource locateSubResource() {
+        return new InstrumentedSubResource();
+    }
 }
